@@ -12,18 +12,19 @@ from py_ocpi.tokens.v_2_2_1.api import cpo_router as tokens_cpo_2_2_1_router
 from py_ocpi.cdrs.v_2_2_1.api import cpo_router as cdrs_cpo_2_2_1_router
 from py_ocpi.versions.api import router as versions_router
 from py_ocpi.versions.enums import VersionNumber
-from py_ocpi.adapter import get_adapter
-from py_ocpi.crud import get_crud
+from py_ocpi.versions.schemas import Version
+from py_ocpi.core.dependencies import get_crud, get_adapter, get_versions
 from py_ocpi.core.enums import RoleEnum
 from py_ocpi.core.config import settings
+from py_ocpi.core.data_types import URL
 
 
 def get_application(
-    version: VersionNumber,
+    version_numbers: List[VersionNumber],
     roles: List[RoleEnum],
     crud: Any,
     adapter: Any,
-):
+) -> FastAPI:
     _app = FastAPI(
         title=settings.PROJECT_NAME,
         docs_url=f'/{settings.OCPI_PREFIX}/docs',
@@ -37,12 +38,13 @@ def get_application(
         allow_methods=["*"],
         allow_headers=["*"],
     )
-    if version == VersionNumber.v_2_2_1:
+    versions = []
+    if VersionNumber.v_2_2_1 in version_numbers:
         _app.include_router(
             versions_router,
             prefix=f'/{settings.OCPI_PREFIX}',
         )
-        if RoleEnum.CPO in roles:
+        if RoleEnum.cpo in roles:
             _cpo_router = APIRouter(
             )
             _cpo_router.include_router(
@@ -69,10 +71,17 @@ def get_application(
 
             _app.include_router(
                 _cpo_router,
-                prefix=f'/{settings.OCPI_PREFIX}/cpo',
+                prefix=f'/{settings.OCPI_PREFIX}/cpo/{VersionNumber.v_2_2_1}',
                 tags=['CPO']
             )
 
+            versions.append(
+                Version(
+                    version=VersionNumber.v_2_2_1,
+                    url=URL(f'https://{settings.OCPI_HOST}/{settings.OCPI_PREFIX}/cpo/{VersionNumber.v_2_2_1}')
+                ).dict(),
+            )
+
     def override_get_crud():
         return crud
 
@@ -83,4 +92,9 @@ def get_application(
 
     _app.dependency_overrides[get_adapter] = override_get_adapter
 
+    def override_get_versions():
+        return versions
+
+    _app.dependency_overrides[get_versions] = override_get_versions
+
     return _app
